@@ -1,10 +1,11 @@
-from re import compile, match
+from functools import partial
+from datetime import datetime
+from io import SEEK_END
+from operator import attrgetter
 from os import scandir
 import os, stat
-from datetime import datetime
-from operator import attrgetter
 from pathlib import Path
-from functools import partial
+from re import compile, match
 
 
 def files(path):
@@ -44,3 +45,17 @@ class FileStat:
     def age(self):
         delta = datetime.now() - self.mtime
         return delta.days
+
+
+def last_lines(path, n_lines, max_line_len=99):
+    offset = n_lines * max_line_len
+    with open(path, 'rb') as inp:
+        try:
+            inp.seek(-offset, SEEK_END)
+        except OSError:
+            inp.seek(0)
+        raw = inp.read()
+    lines = raw.decode().split('\n')
+    last = lines[-n_lines:]
+    return last
+
